#
# spec file for package ppp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _group dialout
Name:           ppp
VCS: https://src.suse.de/SLFO-pool/ppp#f11ff9b5122254cca2be8d713a9b18272941345f5180bc3f0dccc24712e92d2c
Version:        2.4.9
Release:        slfo.1.1_1.2
Summary:        The Point to Point Protocol for Linux
License:        BSD-3-Clause AND LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Productivity/Networking/PPP
URL:            https://ppp.samba.org
Source0:        https://download.samba.org/pub/ppp/ppp-%{version}.tar.gz
Source1:        https://download.samba.org/pub/ppp/ppp-%{version}.tar.gz.asc
# templates for secrets
Source2:        pap-secrets.template
Source3:        chap-secrets.template
# config for pam
Source4:        ppp.pamd
# options and filters files
Source5:        options
Source6:        filters
# several peers file
Source7:        modem-peers
Source8:        pppoe-peers
Source9:        pppoe-rp-peers
Source10:       pppoatm-peers
Source11:       ppp-peers
Source12:       pptp-peers
Source13:       pppoe-discovery.8.gz
# modem files
Source14:       modem.chat
Source15:       modem@.service
Source16:       modem.rules
# https://www.kernel.org/doc/wot/paulus.html
Source17:       %{name}.keyring
# PATCH-FEATURE-OPENSUSE ppp-smpppd.patch -- Add more log output for smpppd (move from debug to info log)
Patch0:         ppp-smpppd.patch
# PATCH-FIX-OPENSUSE ppp-pie.patch -- Build position independent code
Patch1:         ppp-pie.patch
# PATCH-FIX-OPENSUSE ppp-lib64.patch -- Install into lib64 on 64bit systems
Patch2:         ppp-lib64.patch
# PATCH-FIX-UPSTREAM ppp-var_run_resolv_conf.patch -- Move resolv.conf to /var/run
Patch3:         ppp-var_run_resolv_conf.patch
# PATCH-FIX-UPSTREAM ppp-fix-bashisms.patch -- Remove bashism from posix shell interpreted script https://github.com/ppp-project/ppp/issues/348
Patch4:         ppp-fix-bashisms.patch
# PATCH-FIX-UPSTREAM ppp-fork-fix.patch -- fix safe_fork to not close needed file descriptors
Patch5:         ppp-fork-fix.patch
# misc tiny stuff
Patch6:         ppp-misc.patch
# PATCH-FIX-UPSTREAM ppp-fork-fix.patch -- fix E: executable-stack (Badness: 10000) /usr/sbin/pppd
Patch7:         ppp-compiling-with-clang-encounters-an-error-in-eap-tls..patch
# Of cause any other compatible libc would work, like musl, but 2.24 required for SOL_NETLINK
BuildRequires:  glibc-devel >= 2.24
BuildRequires:  libpcap-devel
BuildRequires:  linux-atm-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
Requires:       group(%{_group})
Requires(pre):  group(%{_group})

%description
The ppp package contains the PPP (Point-to-Point Protocol) daemon,
pppd, additional PPP utilities, documentation, and sample files. PPP
provides a method for transmitting IP and IPX datagrams over serial
point-to-point links, for example over a modem. The PPP daemon handles
the details of setting up a PPP link including configuring the network
interface and performing the PPP negotiations.

%package devel
Summary:        Header Files Required for Developing Plugins for pppd
Group:          Development/Libraries/C and C++
Requires:       ppp = %{version}

%description devel
The package ppp-devel contains C header files required for developing
plugins for the pppd.

%package modem
Summary:        Automatic redial for any USB modem supported by the kernel
Group:          System/Kernel
Requires:       ppp
Requires:       udev
Requires:       group(dialout)
BuildArch:      noarch

%description modem
This package contains peer, chat script, systemd unit and udev rule for
automatic redial when connecting any USB modem supported by the kernel.
For disable automatic redial (by default enabled for all), run
sudo systemctl mask modem@0.service
For enable again automatic redial, run
sudo systemctl unmask modem@0.service
"0" after "@" is the serial number of the modem, if you have more than one,
you can disable unnecessary or disable everything.

%prep
%setup -q
%patch0
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5
%patch6
%patch7 -p1

%if "%{_lib}" == "lib64"
%patch2 -p1
%endif

sed -i -e '1s/local\///' scripts/secure-card
find scripts -type f | xargs chmod a-x
find -type f -name '*.orig' | xargs rm -f

# Have to patch this in the Makefile, because setting it on the make
# command line only is not enough.
sed -i '/#HAVE_LIBATM/s/#//' pppd/plugins/pppoatm/Makefile.linux

%build
%configure --cflags "%{optflags} -fno-strict-aliasing -fPIC $SP"
%make_build CHAPMS=y CBCP=y HAS_SHADOW=y USE_PAM=y FILTER=y HAVE_INET6=y HAVE_LOGWTMP=y

%install
make install DESTDIR=%{buildroot}%{_prefix}
install -dm 750 %{buildroot}%{_sysconfdir}/ppp
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/ppp/options
install -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/ppp/filters
install -m 600 %{SOURCE2} %{buildroot}%{_sysconfdir}/ppp/pap-secrets
install -m 600 %{SOURCE3} %{buildroot}%{_sysconfdir}/ppp/chap-secrets
install -d 755 %{buildroot}%{_sysconfdir}/ppp/peers
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/ppp/peers/modem
install -m 644 %{SOURCE8} %{buildroot}%{_sysconfdir}/ppp/peers/pppoe
install -m 644 %{SOURCE9} %{buildroot}%{_sysconfdir}/ppp/peers/pppoe-rp
%ifnarch mips s390 s390x
install -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/ppp/peers/pppoatm
%endif
install -m 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/ppp/peers/ppp
install -m 644 %{SOURCE12} %{buildroot}%{_sysconfdir}/ppp/peers/pptp
%if 0%{?suse_version} > 1500
install -d 755 %{buildroot}%{_pam_vendordir}
install -m 644 %{SOURCE4} %{buildroot}%{_pam_vendordir}/ppp
%else
install -d 755 %{buildroot}%{_sysconfdir}/pam.d
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/pam.d/ppp
%endif
install -m 644 %{SOURCE13} %{buildroot}%{_mandir}/man8/pppoe-discovery.8.gz
install -Dm 644 %{SOURCE14} %{buildroot}%{_sysconfdir}/ppp/chatscripts/modem.chat
install -Dm 644 %{SOURCE15} %{buildroot}%{_unitdir}/modem@.service
install -Dm 644 %{SOURCE16} %{buildroot}%{_udevrulesdir}/90-modem.rules

%if 0%{?suse_version} > 1500
%pre
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in pam.d/ppp ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/etc, restore just created .rpmsave
for i in pam.d/ppp ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files
%attr(0750,root,root) %dir %{_sysconfdir}/ppp
%dir %{_sysconfdir}/ppp/peers
%config(noreplace) %{_sysconfdir}/ppp/options
%config(noreplace) %{_sysconfdir}/ppp/filters
%config(noreplace) %{_sysconfdir}/ppp/pap-secrets
%config(noreplace) %{_sysconfdir}/ppp/chap-secrets
%config(noreplace) %{_sysconfdir}/ppp/peers/p*
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/ppp
%else
%config(noreplace) %{_sysconfdir}/pam.d/ppp
%endif
%doc FAQ README* SETUP scripts PLUGINS
%{_mandir}/man?/*.?%{ext_man}
%attr(-,root,%{_group}) %{_sbindir}/pppd
%{_sbindir}/chat
%{_sbindir}/pppdump
%{_sbindir}/pppstats
%{_sbindir}/pppoe-discovery
%dir %{_libdir}/pppd
%dir %{_libdir}/pppd/%{version}
%attr(0755,root,root) %{_libdir}/pppd/%{version}/*.so

%files devel
%{_includedir}/pppd

%files modem
%dir %{_sysconfdir}/ppp/peers
%config(noreplace) %{_sysconfdir}/ppp/peers/modem
%dir %{_sysconfdir}/ppp/chatscripts
%config(noreplace) %{_sysconfdir}/ppp/chatscripts/modem.chat
%{_unitdir}/modem@.service
%dir %{_udevrulesdir}
%{_udevrulesdir}/90-modem.rules

%changelog
* Wed Dec 28 2022 schubi@suse.com
- Migration of PAM settings to /usr/lib/pam.d.
* Thu May 26 2022 mliska@suse.cz
- Add ppp-compiling-with-clang-encounters-an-error-in-eap-tls..patch
  that fixed the following rpmlint error:
  executable-stack (Badness: 10000) /usr/sbin/pppd
* Mon May 23 2022 rpm@fthiessen.de
- Update to version 2.4.9
  * Support for new EAP (Extensible Authentication Protocol) methods
  * Support for EAP-TLS
  * Support for EAP-MSCHAPv2
  * New pppd options:
  * chap-timeout
  * chapms-strip-domain
  * replacedefaultroute
  * noreplacedefaultroute
  * ipv6cp-accept-remote
  * lcp-echo-adaptive
  * ip-up-script
  * ip-down-script
  * ca
  * capath
  * cert
  * key
  * crl-dir
  * crl
  * max-tls-version
  * need-peer-eap
  * Fixes for CVE-2020-8597 and CVE-2015-3310.
  * The rp-pppoe plugin has been renamed to pppoe, to distinguish it
    from the upstream rp-pppoe code.  Its options have changed names,
    but the old names are kept as aliases.
  * Many bug fixes and cleanups.
- Drop upstream fixed patches
  * ppp-2.4.3-winbind-setuidfix.patch
  * fix-header-conflict.patch
  * ppp-CVE-2015-3310.patch
  * ppp-CVE-2020-8597.patch
  * ppp-cifdefroute.patch
  * ppp-higher-speeds.patch
  * ppp-2.4.3-strip.diff
  * ppp-filter.patch
  * ppp-__P.patch
- Drop upstream resolved ppp-make.patch use `--cflags` configure
  switch instead
* Thu Mar 10 2022 ilya@ilya.cf
- Removed Wants=network.target from modem@.service (bsc#1196359).
* Mon Nov  9 2020 ilya@ilya.cf
- Refresh spec-file via spec-cleaner and manual optimizations.
  * Removed obsolete constructs (creating dialout group via shadow).
* Fri Oct  9 2020 dimstar@opensuse.org
- Fix build with RPM 4.16: error: bare words are no longer
  supported, please use "...":  lib64 == lib64.
* Mon Aug  3 2020 max@suse.com
- New version 2.4.8.
  * New pppd options have been added:
  * ifname, to set the name for the PPP interface device
  * defaultroute-metric, to set the metric for the default route
  * defaultroute6, to add an IPv6 default route (with
    nodefaultroute6 to prevent adding an IPv6 default route).
  * up_sdnotify, to have pppd notify systemd when the link is up.
  * The rp-pppoe plugin has new options:
  * host-uniq, to set the Host-Uniq value to send
  * pppoe-padi-timeout, to set the timeout for discovery packets
  * pppoe-padi-attempts, to set the number of discovery attempts.
  * Added the CLASS attribute in radius packets.
  * Fixed warnings and issues found by static analysis.
- Obsoleted patches:
  * ppp-2.4.3-pppoatm.diff
  * ppp-2.4.4-strncatfix.patch
  * ppp-2.4.6-ifname.diff
  * ppp-2.4.7-DES-openssl.patch
  * ppp-2.4.7.tar.gz.asc
  * ppp-send-padt.patch
- Patches that got renamed, because they needed rediffing:
  * ppp-2.4.1-higher-speeds.diff -> ppp-higher-speeds.patch
  * ppp-2.4.1-higher-speeds.diff -> ppp-higher-speeds.patch
  * ppp-2.4.2-__P.diff -> ppp-__P.patch
  * ppp-2.4.2-cifdefroute.diff -> ppp-cifdefroute.patch
  * ppp-2.4.2-pie.patch -> ppp-pie.patch
  * ppp-2.4.2-smpppd.diff -> ppp-smpppd.patch
  * ppp-2.4.3-filter.diff -> ppp-filter.patch
  * ppp-2.4.3-fork-fix.diff -> ppp-fork-fix.patch
  * ppp-2.4.4-var_run_resolv_conf.patch -> ppp-var_run_resolv_conf.patch
  * ppp-2.4.6-lib64.patch -> ppp-lib64.patch
  * ppp-2.4.6-make.diff -> ppp-make.patch
  * ppp-2.4.6-misc.diff -> ppp-misc.patch
  * ppp-2.4.7-fix-bashisms.patch -> ppp-fix-bashisms.patch
- bsc#1172916: Fix an outdated comment for lcp-echo-interval.
* Tue May 19 2020 dimstar@opensuse.org
- Fixup previous fix: use the defined macro %%_unitdir for the
  systemd unit.
* Thu May  7 2020 pgajdos@suse.com
- /usr/lib/systemd instead %%{_libexecdir}/systemd
* Sun Apr 26 2020 andreas.stieger@gmx.de
- add upstream signing keyring and verify source signature
* Tue Mar  3 2020 max@suse.com
- Add pam_keyinit to /etc/pam.d/ppp (bsc#1144055).
* Fri Feb  7 2020 max@suse.com
- CVE-2020-8597, bsc#1162610, ppp-CVE-2020-8597.patch: rhostname
  buffer overflow in the  eap_request and eap_response functions.
* Thu Oct  4 2018 schwab@suse.de
- ppp-2.4.7-DES-openssl.patch: Use openssl instead of libcrypt for DES
* Fri Nov 24 2017 ilya@ilya.cf
- Refresh spec-file via spec-cleaner.
- Add ppp-modem package for automatic redial to mobile provider.
* Thu Nov 23 2017 ilya@ilya.cf
- Add Requires group(dialout) (boo#1067511).
* Tue Jun 13 2017 kukuk@suse.com
- Add /etc/ppp, this directory is no longer part of filesystem.
  Most likely requiring sysconfig would be necessary.
* Sat Jun 10 2017 meissner@suse.com
- ppp-2.4.2-pie.patch: also enable PIE for /usr/sbin/pppstats
* Fri Dec  9 2016 max@suse.com
- Use system-wide libatm instead of local copy (boo#1013567).
* Mon Oct 17 2016 schwab@suse.de
- fix-header-conflict.patch: avoid conflict with kernel headers
* Fri Nov 13 2015 max@suse.com
- Added ppp-CVE-2015-3310.patch:
  Fix for bnc#927841, CVE-2015-3310: Fix buffer overflow in radius
  plug-in's rc_mksid().
* Wed Nov 19 2014 ledest@gmail.com
- fix bashisms in redialer script
- add patches:
  * ppp-2.4.7-fix-bashisms.patch
* Thu Aug 21 2014 max@suse.com
- Update to 2.4.7:
  * Fixed a potential security issue in parsing option files
    (CVE-2014-3158, bnc#891489).
  * There is a new "stop-bits" option, which takes an argument of
    1 or 2, indicating the number of stop bits to use for async serial
    ports.
  * Various bug fixes.
* Thu Mar 20 2014 aj@ajaissle.de
- Update to 2.4.6
  + Man page updates.
  + Several bug fixes.
  + Options files can now set and unset environment variables for
    scripts.
  + The timeout for chat scripts can now be taken from an environment
    variable.
  + There is a new option, master_detach, which allows pppd to detach
    from the controlling terminal when it is the multilink bundle master
    but its own link has terminated, even if the nodetach option has
    been given.
- Removed the following patches;
  - ppp-2.4.2-logwtmp.diff -- now checks for HAVE_LOGWTMP
  - ppp-2.4.3-demand-fix.diff -- using 'status'
  - ppp-terminate-correct.patch -- upstream inclusion
- Rebased the following patches:
  * ppp-2.4.3-make.diff as ppp-2.4.6-make.diff
  * ppp-2.4.2-misc.diff as ppp-2.4.6-misc.diff
  * ppp-2.4.2-ifname.diff as ppp-2.4.6-ifname.diff
  * ppp-2.4.4-lib64.patch as ppp-2.4.6-lib64.patch
- Url changed to ppp.samba.org
- Use macros in spec file
- We dont need to cleanup the buildroot
* Mon Sep  2 2013 max@suse.com
- Add ppp-terminate-correct.patch, fix the pppd's hang after exit
  (bnc#693469).
* Wed Jul 24 2013 max@suse.com
- ppp-send-padt.patch: Send PADT at the end of a PPPoE session.
* Fri Mar  1 2013 cfarrell@suse.com
- license update: BSD-3-Clause and LGPL-2.1+ and GPL-2.0+
  GPL-2.0 matches found in ppp-2.4.5/include/linux/if_pppol2tp.h
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Fri Aug 12 2011 coolo@novell.com
- remove extra dependencies from doc files
* Wed Jan  5 2011 coolo@novell.com
- refresh patch
* Wed Jan  5 2011 aj@suse.de
- Fix build of pppol2tp - remove local copy of if_pppol2tp.h
  that is out of sync with kernel definition.
- Remove ppp-makedevice.patch, it is obsolete.
* Wed Jan  5 2011 aj@suse.de
- Update to final 2.4.5 version with these changes:
  * Pppd now works better with 3G modems that do strange things such as
    sending IPCP Configure-Naks with the same values over and over again.
  * Bugfixes
* Tue Apr  6 2010 coolo@novell.com
- replace %%PACKAGE_VERSION with %%version to fix build
* Tue Jan  5 2010 jengelh@medozas.de
- enable parallel building
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Oct 14 2009 crrodriguez@opensuse.org
- build with -fno-strict-aliasing, dereferencing pointer 'svc'
  does break strict-aliasing rules.
- give the package a more meaningful version number
* Thu Oct 23 2008 lnussel@suse.de
- fix wrong permissions of pppol2tp.so
- fix invalid interpreter in secure-card script
* Fri Sep 12 2008 hvogel@suse.de
- update to 2.4.5 (git:07bcc935f7a10bc5d78325fc53a6ac9bdf2aad6a)
  * pppd can now operate in a mode where it doesn't request
    the peer's IP address, as some peers refuse to supply an IP
    address.
  * included PPP over L2TP plugin
  * Add L2TP support
  * Various bug fixes
* Tue Jul 22 2008 hvogel@suse.de
- move the resolv.conf written by pppd to /var/run [bnc#401648]
* Wed May 21 2008 hvogel@suse.de
- add man page of pppoe-discovery [bnc#392784]
* Thu Apr  3 2008 hvogel@suse.de
- move plugin directory to %%_libdir [bnc#358927]
* Thu Aug 23 2007 hvogel@suse.de
- Work around pppoatm MTU problems. [#301678]
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Tue Dec 19 2006 meissner@suse.de
- fixed strncat usage in radius plugin.
* Wed Sep 13 2006 hvogel@suse.de
- Argh, really re-enable the patch.
* Thu Sep  7 2006 hvogel@suse.de
- fix and reenable "replace default route" patch
* Mon Aug 21 2006 kukuk@suse.de
- Use include statements in PAM config file
* Mon Aug  7 2006 mskibbe@suse.de
- update to version 2.4.4 which
  o fix some bugs
  o fix bug #179560 (MTU overwritten by pppoe plugin)
* Tue May 30 2006 meissner@suse.de
- check return code of setuid in winbind plugin. #179660
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 max@suse.de
- Enabled IPv6 support (#145246).
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jan 13 2006 hvogel@suse.de
- Make use of Stack Protector
* Wed Nov  2 2005 hvogel@suse.de
- expand strict-aliasing patch to the radius plugin
* Mon Oct 17 2005 arvin@suse.de
- fixed pptp peers file
* Wed Oct 12 2005 hvogel@suse.de
- Add -fno-strict-aliasing to pppd cflags. Added
  * ppp-2.4.3-no-strict-aliasing.patch
* Wed Oct  5 2005 hvogel@suse.de
- fix too few arguments to a *printf function. modified
  * ppp-2.4.2-misc.diff
- make use of optflags everywhere. modified
  * ppp-2.4.3-optflags.patch
* Sun Aug  7 2005 kkeil@suse.de
- fix filter stuff for libpcap version 0.9.3 (see #102460)
* Sat Jul  2 2005 hvogel@suse.de
- use optflags also for pppoatm plugin
* Tue Jun 28 2005 kkeil@suse.de
- fix some problems with 2.4.3 (#80468)
  * solve not working dial on demand after a connection was shut
    down first time
  * fix safe_fork to not close needed file descriptors
* Thu Jun 23 2005 ro@suse.de
- build with -fPIC/-pie
* Thu Apr 21 2005 arvin@suse.de
- fixed compilation of pppoatm plugin (bug #79295)
* Fri Mar 18 2005 kkeil@suse.de
- fix filter stuff and DOD (#73663)
* Mon Feb 28 2005 kkeil@suse.de
- undefined fd is a bad idea, incremental fix for #66786
* Mon Feb 28 2005 hvogel@suse.de
- enable device creating if it does not exist (Bug #66786)
* Mon Dec 13 2004 hvogel@suse.de
- get rid of the pppoam patch
* Fri Dec 10 2004 hvogel@suse.de
- update to version 2.4.3 which includes:
  o Various fixes and enhancements to the radius and rp-pppoe
  plugins have been added.
  o There is a new option, child-timeout, which sets the length
  of time that pppd will wait for child processes
  o There is a new winbind plugin, from Andrew Bartlet of the Samba
  team, which provides the ability to authenticate the peer
  against an NT domain controller using MS-CHAP or MS-CHAPV2.
  o There is a new pppoatm plugin
* Tue Sep 21 2004 kkeil@suse.de
- fix dial on demand; outbound must flagged with 1 not 0xff (#45694)
* Sun Sep 12 2004 kukuk@suse.de
- Don't use __P from glibc
* Tue Aug 24 2004 kkeil@suse.de
- use DLT_PPP_WITHDIRECTION for the filters to be compatible with
  kernel 2.6.8
* Tue Jul 20 2004 arvin@suse.de
- added option to rename ppp interface (experimental)
* Mon Jul 19 2004 arvin@suse.de
- allow all names as Ethernet interfaces (bug #43048)
* Tue Jul 13 2004 arvin@suse.de
- removed non-ascii character from option file
* Fri May 28 2004 kkeil@suse.de
- correct fix for the DOD filter rule paket header (see bug #34724)
* Fri Apr 16 2004 mmj@suse.de
- Void functions should be declared as such
* Wed Mar 31 2004 arvin@suse.de
- fixed filter rules for dial on demand (see bug #34724)
* Wed Feb 18 2004 arvin@suse.de
- fixed setting of filter rules (bug #34569)
* Fri Feb 13 2004 arvin@suse.de
- updated pppoatm plugin (bug #34543)
- fixed ctl-c bug
* Fri Feb 13 2004 arvin@suse.de
- updated to version 2.4.2, main features:
  - new upstream PPPoE plugin implementation
  - new upstream MPPE implementation
  - many protocols (CHAP, CBCP, EAP, ECP) added or updated
- build package as non-root user
- build sub-package ppp-devel with header files required for
  extra plugins
* Thu Feb 12 2004 arvin@suse.de
- removed outdated samples
- some cleanup
* Thu Feb 12 2004 ro@suse.de
- adapt to change in libpcap: include moved to pcap_bpf.h
* Mon Jan 26 2004 arvin@suse.de
- allow higher serial speeds (see bug #34053)
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Fri Jan  9 2004 kukuk@suse.de
- Fix compiler warnings
* Wed Aug 13 2003 arvin@suse.de
- allow vlan devices for pppoe (bug #28645)
* Mon Jun 30 2003 arvin@suse.de
- fixed closing of pppoatm (bug #27315)
- fixed pppoe on ppc (bug #27575)
* Thu Jun  5 2003 arvin@suse.de
- converted MSCHAPv2-fix patch to unix format as new patch
  doesn't like dos anymore
* Tue Jun  3 2003 arvin@suse.de
- added peers file for pptp
* Mon May 26 2003 arvin@suse.de
- adapted neededforbuild to linux-atm changes
* Thu May 22 2003 okir@suse.de
- prevent buffer overflow in MPPE (#27062)
* Wed Mar 12 2003 arvin@suse.de
- activate filter rules per default (bug #25134)
* Sat Jan 18 2003 arvin@suse.de
- added config file with some filter rules
* Fri Jan 10 2003 arvin@suse.de
- Reactivated option noipdefault in default options file since
  some providers can't handle a suggested local ip address. Can't
  reproduce the wrong behaviour of the pppd mentioned in bug #1751
  so the change is ok.
* Thu Dec 12 2002 arvin@suse.de
- removed absolute paths from pam configuration file
* Wed Nov 13 2002 arvin@suse.de
- fixed multi-line string literals
* Thu Oct 24 2002 arvin@suse.de
- fixed callback phone number handling (bug #9659 and #18408)
- activated patches added on Aug. 1st
* Fri Aug 23 2002 arvin@suse.de
- remove a warning message in the log (bug #18254)
- removed obsolete peers file demand
* Tue Aug  6 2002 arvin@suse.de
- added "plain old modem" peers file (related to bug #17341)
* Thu Aug  1 2002 bk@suse.de
- add patches recommeded for pptp which also fix bug 17097
* Thu Jul 25 2002 arvin@suse.de
- disable pppoatm plugin on s390 and s390x
* Mon Jul  8 2002 arvin@suse.de
- removed setuid bits from pppd (bug #16860)
* Thu May 16 2002 arvin@suse.de
- compile with packet filter support
* Wed May 15 2002 arvin@suse.de
- enable more debugging for pppoe if the pppd gets the debug
  option
* Mon May 13 2002 ro@suse.de
- fix build on x86_64
* Fri Apr 19 2002 arvin@suse.de
- disable pppoatm plugin on mips (since linux-atm does not build)
* Tue Apr 16 2002 arvin@suse.de
- turn off debugging by default
* Wed Mar 13 2002 arvin@suse.de
- better mtu handling as workaround for broken dsl providers
* Fri Feb  8 2002 arvin@suse.de
- fixed error handling in passwordfd plugin
* Fri Feb  8 2002 okir@suse.de
- applied security fix to zlib
* Tue Feb  5 2002 arvin@suse.de
- more log output without debug option so that the smpppd does
  not require the debug option
- removed debug option from peers files
- use %%{_mandir}
* Wed Jan 30 2002 arvin@suse.de
- use buildroot
- compile pppoatm plugin on all archs again
* Fri Jan 11 2002 arvin@suse.de
- added terminating NULL in options list of passwordfd plugin
* Fri Jan 11 2002 arvin@suse.de
- don't compile pppoatm plugin on axp and s390
* Wed Jan  9 2002 arvin@suse.de
- added "modprobe pppoatm" in pppoatm plugin
* Tue Jan  8 2002 arvin@suse.de
- fixed compiling on ia64
* Mon Jan  7 2002 arvin@suse.de
- added atm support
- modified peers files for new network configuration
* Mon Nov  5 2001 arvin@suse.de
- set MTU and MRU to 1492 (to prevent problems for DSL)
* Thu Sep 27 2001 arvin@suse.de
- added rc-pppoe peers file
* Wed Sep 19 2001 arvin@suse.de
- added patch only-eth.dif: makes pppoe plugin only accect eth*
  as device and thus prevents kernel from trying to load dozens
  of modules (bug #10845)
* Tue Aug 28 2001 arvin@suse.de
- strip plugins
* Mon Aug 13 2001 arvin@suse.de
- updated pppoe patch to ppp-2.4.1-pppoe.patch4
* Thu Aug  9 2001 arvin@suse.de
- added Obsoletes ppp-soho
- added peers file pppoe
* Tue Jul 17 2001 arvin@suse.de
- added directories to file list
* Wed Jul 11 2001 arvin@suse.de
- removed obsolete generation of pap and chap secrets form
  wvdial provider list
* Sun Jun 24 2001 arvin@suse.de
- updated to version 2.4.1
- added peers file "demand" (from package pppoed)
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Fri Apr 20 2001 arvin@suse.de
- added options lcp-max-configure 60 and lcp-restart 2
* Fri Mar 30 2001 arvin@suse.de
- added mppe patch
- search for plugins in /usr/lib/pppd/<version> (backport from
  pppd 2.4.1)
- moved all plugins to /usr/lib/pppd/<version>
* Wed Feb 28 2001 arvin@suse.de
- moved all plugins to /usr/lib/pppd/plugins
* Thu Feb 15 2001 arvin@suse.de
- included pppoe patch from Michal Ostrowski
* Thu Nov  9 2000 arvin@suse.de
- updated to version 2.4.0
* Mon Sep 11 2000 arvin@suse.de
- Fixed plugin passwordfd for chap.
* Mon Jul 31 2000 arvin@suse.de
- Added (commented) option "maxfail 3" to options. Partly fix
  for bug #3637.
* Thu Jul 13 2000 arvin@suse.de
- removed directory /var/state/pppd from spec file. It is not
  needed and only got there by accident.
* Mon Jul 10 2000 bk@suse.de
- fixed bug with replacedefaultroute and dial on demand(route was lost)
- fixed Open message of demand patch for ICMP(was displayed as UDP)
* Tue Jul  4 2000 arvin@suse.de
- Support for dial on demand with sync ppp.
- On dial on demand log witch packed caused the connect. Example:
    Open UDP 212.185.229.193:2048 -> 216.32.74.51:22926
- Fixed plugin passwordfd for dial on demand.
* Mon Jun  5 2000 arvin@suse.de
- fixed bug in plugin passwordfd
* Fri Jun  2 2000 arvin@suse.de
- added plugin passwordfd to read password via a pipe
- replacedefaultroute option fixed for pppd demand
* Thu Mar  2 2000 ro@suse.de
- manpages ..
* Thu Mar  2 2000 bk@suse.de
- fixed patch path strip count for ppp-2.3.11.dif
- added comment about modem and local options to /etc/ppp/options
* Wed Mar  1 2000 bk@suse.de
- copied ppp-2.3.11.dif from ppp_ssl(fixes MANPATH) and filelist fixed.
* Fri Feb 25 2000 bk@suse.de
- removed priviledged property from (no)replacedefaultroute, this
  way wvdial can set it in /etc/ppp/peers/wvdial with call wvdial.
* Fri Feb 25 2000 bk@suse.de
- disabled new replacedefaultroute option per default, can be controlled
  thru the replacedefaultroute and noreplacedefaultroute options.
* Thu Feb 24 2000 bk@suse.de
- wrote patch which replaces the old defaut route on successfully
  completed IPCP negotiation unless the included noreplacedefaultroute
  option is given. Documented in the man page and /etc/ppp/options.
  On connection shutdown, the old default route is restored automatically.
  Nice feature for many people with laptops which have a default
  route set trough their ethernet and want go online with their
  modem if not connected to the ethernet. Should reduce support
  load in this area dramatically.
* Sun Feb 20 2000 bk@suse.de
- only change tty perms really needed, will avoid the loosing tty
  perms bug (bug #1831 and 1361)
- disabled noipdefault in the default options file for static IP addresses
  and dial-in. wvdial still passes it to pppd if Force Address is not
  set in wvdial.conf, so no problem. (Fix for bug #1751)
* Fri Feb 11 2000 bk@suse.de
- generate pap and chap secrets with callbycall.secrets
- Makefile.Linux merged into the spec file and dropped from diff
* Sun Jan 16 2000 bk@suse.de
- update to ppp-2.3.11
* Fri Oct 29 1999 bk@suse.de
- added logins for german call-by-call providers to the secrets
- removed suse dialin scripts
* Sun Oct 24 1999 olh@suse.de
- add some sample scripts, minor sample changes
* Sun Oct 24 1999 bk@suse.de
- fix for empty files in /usr/doc/packages/ppp (olh: thanks for the report!!)
* Sun Oct 10 1999 bk@suse.de
- update to ppp-2.3.10
- split up diff
- removed not installed ppplogin which also didn't appear in the
  file list lately
- removed proxyarp from the default options file
- force pppd use the glibc's logwtmp instead of implementing its own
  (patch for ppp-2.3.9, but is preferred for 2.3.10 also)
- added the samples to /usr/doc/packages/ppp
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug 30 1999 kukuk@suse.de
- add pppdump.8
* Thu Aug 19 1999 bk@suse.de
- added documentation
* Thu Jul 29 1999 bs@suse.de
- set /etc/ppp to 750, root.dialout
- use noauth in /etc/ppp/options
* Sat Jul 17 1999 bk@suse.de
- /etc/ppp/option fixed wins-addr, corrected to ms-wins
* Mon Jun 14 1999 kukuk@suse.de
- Enable PAM support, add ppp.pamd
* Sat May 22 1999 bk@suse.de
- update to ppp-2.3.8 using diff from jurix
- added ppp-2.3.8-patch1
- marked /etc/ppp/options as noreplace
* Mon Dec 14 1998 tmg@suse.de
- changed default config
* Wed Dec  9 1998 bs@suse.de
- marked config files as noreplace
* Tue Nov 24 1998 ro@suse.de
- don't pack if_ppp.h (delivered by glibc)
* Tue Oct  6 1998 ro@suse.de
- update to ppp-2.3.5 using diff from jurix
- re-activate ppp_available in sys-linux.c
* Mon Nov  3 1997 ro@suse.de
- install include files in usr/include/net before compilation
* Wed Apr 30 1997 florian@suse.de
- create eror output file with perm 0600
- pppd is only executable for group "dialout"
* Thu Jan  2 1997 florian@suse.de
- add bug-fix
- add ipx support
